@@ -49,9 +49,9 @@ module Diff; end unless defined? Diff
 #          a x b y c z p d q
 #    a b c a x b y c z
 module Diff::LCS
-  VERSION = "1.5.1"
 end
 
+require "diff/lcs/version"
 require "diff/lcs/callbacks"
 require "diff/lcs/internals"
 
@@ -62,11 +62,12 @@ module Diff::LCS
   #   lcs = seq1.lcs(seq2)
   #
   # A note when using objects: Diff::LCS only works properly when each object
-  # can be used as a key in a Hash, which typically means that the objects must
-  # implement Object#eql? in a way that two identical values compare
-  # identically for key purposes. That is:
+  # can be used as a key in a Hash. This means that those objects must implement
+  # the methods +#hash+ and +#eql?+ such that two objects containing identical values
+  # compare identically for key purposes. That is:
   #
-  #   O.new('a').eql?(O.new('a')) == true
+  #   O.new('a').eql?(O.new('a')) == true &&
+  #   O.new('a').hash == O.new('a').hash
   def lcs(other, &block) # :yields: self[i] if there are matched subsequences
     Diff::LCS.lcs(self, other, &block)
   end
@@ -256,7 +257,7 @@ class << Diff::LCS
   #
   # The methods for <tt>callbacks#match</tt>, <tt>callbacks#discard_a</tt>, and
   # <tt>callbacks#discard_b</tt> are invoked with an event comprising the
-  # action ("=", "+", or "-", respectively), the indicies +i+ and +j+, and the
+  # action ("=", "+", or "-", respectively), the indexes +i+ and +j+, and the
   # elements <tt>A[i]</tt> and <tt>B[j]</tt>. Return values are discarded by
   # #traverse_sequences.
   #
@@ -332,7 +333,7 @@ class << Diff::LCS
         if callbacks.respond_to?(:finished_a) && !run_finished_a
           ax = string ? seq1[-1, 1] : seq1[-1]
           bx = string ? seq2[bj, 1] : seq2[bj]
-          event = Diff::LCS::ContextChange.new(">", (a_size - 1), ax, bj, bx)
+          event = Diff::LCS::ContextChange.new(">", a_size - 1, ax, bj, bx)
           event = yield event if block_given?
           callbacks.finished_a(event)
           run_finished_a = true
@@ -354,7 +355,7 @@ class << Diff::LCS
         if callbacks.respond_to?(:finished_b) && !run_finished_b
           ax = string ? seq1[ai, 1] : seq1[ai]
           bx = string ? seq2[-1, 1] : seq2[-1]
-          event = Diff::LCS::ContextChange.new("<", ai, ax, (b_size - 1), bx)
+          event = Diff::LCS::ContextChange.new("<", ai, ax, b_size - 1, bx)
           event = yield event if block_given?
           callbacks.finished_b(event)
           run_finished_b = true
@@ -421,7 +422,7 @@ class << Diff::LCS
   #                                 occurred.
   #
   # #traverse_balanced might be a bit slower than #traverse_sequences,
-  # noticable only while processing huge amounts of data.
+  # noticeable only while processing huge amounts of data.
   #
   # == Algorithm
   #
@@ -465,7 +466,7 @@ class << Diff::LCS
   # The methods for <tt>callbacks#match</tt>, <tt>callbacks#discard_a</tt>,
   # <tt>callbacks#discard_b</tt>, and <tt>callbacks#change</tt> are invoked
   # with an event comprising the action ("=", "+", "-", or "!", respectively),
-  # the indicies +i+ and +j+, and the elements <tt>A[i]</tt> and <tt>B[j]</tt>.
+  # the indexes +i+ and +j+, and the elements <tt>A[i]</tt> and <tt>B[j]</tt>.
   # Return values are discarded by #traverse_balanced.
   #
   # === Context
@@ -482,7 +483,7 @@ class << Diff::LCS
 
     # Process all the lines in the match vector.
     loop do
-      # Find next match indices +ma+ and +mb+
+      # Find next match indexes +ma+ and +mb+
       loop do
         ma += 1
         break unless ma < matches.size && matches[ma].nil?
